# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # CARRIAGE
    def v1_carriage_carriage_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_carriage_carriage_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:carriage-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # DELIVERY

    def v1_carriage_delivery_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_carriage_delivery_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-carriage:delivery-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
